"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
require("dotenv/config");
const upload_1 = require("../upload");
const log_1 = require("../log");
const file_1 = require("../file");
const env_1 = require("../env");
const cli_progress_1 = require("cli-progress");
const colors = __importStar(require("ansi-colors"));
const log = (0, log_1.createLog)('files');
function createConfig() {
    const ENDPOINT = (0, env_1.envString)('OBJECT_ENDPOINT', '');
    const ACCESS_KEY = (0, env_1.envString)('OBJECT_ACCESS_KEY', '');
    const ACCESS_SECRET = (0, env_1.envString)('OBJECT_ACCESS_SECRET', '');
    const config = {
        region: (0, env_1.envString)('OBJECT_REGION', 'us-east-1'),
        bucketName: (0, env_1.envString)('OBJECT_BUCKET', 'icebox'),
        expirationSeconds: (0, env_1.envInt)('OBJECT_EXPIRATION', 3600) //1 hour
    };
    if (ENDPOINT !== '') {
        config.endpoint = ENDPOINT;
        config.forcePathStyle = true;
    }
    if (ACCESS_KEY !== '' && ACCESS_SECRET !== '') {
        config.credentials = {
            accessKeyId: ACCESS_KEY,
            secretAccessKey: ACCESS_SECRET
        };
    }
    return config;
}
async function process(filePath) {
    const fileInfo = await file_1.File.info(filePath);
    const config = createConfig();
    const progress = new cli_progress_1.SingleBar({
        format: `Printing [${fileInfo.filename}] | ${colors.cyan('{bar}')} | {percentage}% || ETA: {time}`,
        barCompleteChar: '\u2588',
        barIncompleteChar: '\u2591',
        hideCursor: true
    });
    if (!fileInfo.success) {
        log.error(`Error processing file info`, fileInfo.error);
        return;
    }
    console.dir(fileInfo);
    log.info(`Started upload: ${filePath}`);
    progress.start(100, 0, {
        time: 'N/A'
    });
    const result = await (0, upload_1.upload)('test', filePath, config, (progressInfo) => {
        progress.update(Math.floor((progressInfo.loaded / progressInfo.total) * 100.0), { time: 'N/A' });
    });
    if (result.success) {
        progress.update(100, {
            time: 'Done'
        });
    }
    progress.stop();
    if (result.success) {
        log.info(`File ${filePath} uploaded successfully`);
        log.info(`Private URL: ${result.url}`);
    }
    else {
        log.error('Upload failed:', result.error);
    }
}
async function main() {
    /*chokidar.watch('./watch', { ignored: /(^|[/\\])\../ }).on('all', (event : any, path : string) => {
        log.info(`File ${path} changed with event type ${event}`);
    });*/
    process('/Users/matthewmcwilliams9/Desktop/m1554 hd optical printer test.mov');
}
main().catch(log.error);
/*
    const minioResult = await uploadFileToS3('/path/to/your/file.pdf', {
    region: 'us-east-1', // Region can be any string for MinIO
    endpoint: 'https://minio.your-domain.com',
    bucketName: 'your-minio-bucket',
    credentials: {
      accessKeyId: 'your-minio-access-key',
      secretAccessKey: 'your-minio-secret-key'
    },
    forcePathStyle: true, // Important for most S3-compatible services
    expirationSeconds: 3600
  });
  
  // Example 3: DigitalOcean Spaces
  const spacesResult = await uploadFileToS3('/path/to/your/file.pdf', {
    region: 'nyc3', // DigitalOcean datacenter region
    endpoint: 'https://nyc3.digitaloceanspaces.com',
    bucketName: 'your-space-name',
    credentials: {
      accessKeyId: 'your-spaces-key',
      secretAccessKey: 'your-spaces-secret'
    },
    forcePathStyle: true,
    expirationSeconds: 7200 // 2 hours
  });
  
  // Example 4: Wasabi
  const wasabiResult = await uploadFileToS3('/path/to/your/file.pdf', {
    region: 'us-east-1',
    endpoint: 'https://s3.wasabisys.com',
    bucketName: 'your-wasabi-bucket',
    credentials: {
      accessKeyId: 'your-wasabi-access-key',
      secretAccessKey: 'your-wasabi-secret-key'
    },
    forcePathStyle: true,
    expirationSeconds: 86400 // 24 hours
  });
*/ 
//# sourceMappingURL=index.js.map