import { stat } from 'fs/promises';
import type { Stats } from 'fs';
import { basename, resolve } from 'path';

import { size } from '../size';
import { Hashes } from '../hash';

interface FileInfo {
	success : boolean;
	filename? : string;
	original? : string;
	hash? : string;
	size? : number;
	created? : number;
	error? : Error | undefined;
}

export class File {
	public static async info (filePath : string) : Promise<FileInfo> {
		const original : string = resolve(filePath);
		const filename : string = basename(filePath);
		let success : boolean = false;
		let hash : string;
		let fileSize : number;
		let created : number;
		let stats : Stats;
		let error : Error;

		try {
			hash = await Hashes.file(filePath);
		} catch (err) {
			error = err as Error;
			return {
				success,
				error
			};
		}

		try {
			fileSize = await size(filePath)
		} catch (err) {
			error = err as Error;
			return {
				success,
				error
			};
		}

		try {
			stats = await stat(filePath);
			created = stats.birthtimeMs;
		} catch (err) {
			error = err as Error;
			return {
				success,
				error
			};
		}

		success = true;
		return {
			success,
			filename,
			original,
			hash,
			size : fileSize,
			created
		};
	}
}

module.exports = { File };
export type { FileInfo };